Normalizing sparse transform (a la softmax).
Arguments
- dim
The dimension along which to apply sparsemax.
- k
The number of largest elements to partial-sort input over. For optimal performance,
kshould be slightly bigger than the expected number of non-zeros in the solution. If the solution is more than k-sparse, this function is recursively called with a 2*k schedule. IfNULL, full sorting is performed from the beginning.
Examples
if (FALSE) { # \dontrun{
input <- torch::torch_randn(10, 5, requires_grad = TRUE)
# create a top3 alpha=1.5 sparsemax on last input dimension
nn_sparsemax <- sparsemax15(dim=1, k=3)
result <- nn_sparsemax(input)
print(result)
} # }